package
Version:
v0.0.0-...-7bb490a
Opens a new window with list of versions in this module.
Published: Apr 26, 2026
License: MIT
Opens a new window with license information.
Imports: 7
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Config struct {
Telegram Telegram `yaml:"telegram"`
Instagram Instagram `yaml:"instagram"`
YouTube YouTube `yaml:"youtube"`
Facebook Facebook `yaml:"facebook"`
Proxy string `yaml:"proxy"`
}
type Facebook struct {
Cookies string `yaml:"cookies"`
}
type Instagram struct {
Cookies string `yaml:"cookies"`
}
type Telegram struct {
Token string `yaml:"token"`
}
type YouTube struct {
Cookies string `yaml:"cookies"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.